@@ -10,7 +10,7 @@ class FixGrowth(BasicGrowth):
         super().__init__(graph, schema, deg, model_param)
         self.typ = del_typ
 
-    def proceed(self, n, save, attr="cnt"):
+    def proceed(self, n, save=None, attr="cnt"):
         nw_graph = self.gr.clean_copy()
         for node in nw_graph.get_ids():
             nw_graph.set_attr(node, attr, 0)
