@@ -4,7 +4,7 @@ import pandas as pd
 
 from dtg.tail.estimate.hill import HillEstimator
 from dtg.tail.mse import boot_estimate
-from pge.cluster.directed.dir_louvain import best_partition_to
+from pge.cluster.modularity import best_partition_to
 from pge.model.growth.basic import BDiGrowth
 from pge.ranks.rank import estimate_rank
 
